.. climlab-0.2.13 Documentation documentation master file, created by
   sphinx-quickstart on Mon Jan 25 10:23:51 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to the climlab documentation!
=====================================

.. toctree::
    :maxdepth: 4

    intro
    quickstart
    installation
    architecture
    models
    tutorial
    xarray
    api/climlab
    contributing
    references
    license
    support
    contact



.. only:: html

    Indices and tables
    ==================

    * :ref:`genindex`
    * :ref:`modindex`
    * :ref:`search`
